Linear
------------------------

NNX linear layer classes.

.. automodule:: flax.nnx
.. currentmodule:: flax.nnx

.. flax_module::
  :module: flax.nnx
  :class: Conv

.. flax_module::
  :module: flax.nnx
  :class: ConvTranspose

.. flax_module::
  :module: flax.nnx
  :class: Embed

.. flax_module::
  :module: flax.nnx
  :class: Linear

.. flax_module::
  :module: flax.nnx
  :class: LinearGeneral

.. flax_module::
  :module: flax.nnx
  :class: Einsum